<?php
namespace Teknisa\EST\Modules\Relatorios\Controllers;

use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO;

use Zeedhi\Framework\Report\ReportService;

class Est40000MapasPoliciaCivilController {

    protected $dataSourceName = "";
    protected $dataSourceManager;
    protected $environment;
    protected $reportService;
    protected $nrorg;
    
    
    public function __construct($dataSourceManager, $environment, ReportService $reportService) {
        $this->dataSourceManager = $dataSourceManager;
        $this->reportService = $reportService;
        $this->environment = $environment;
        $this->nrorg = $environment->getNrorgTrab();
    }
    
    public function generateReport(DTO\Request\Row $request, DTO\Response $response) {
        
        $row = $request->getRow();
        $reportName = $row['NMRELATORIO'];
        $reportStrategy = $this->getReportStrategyReport($reportName);
        $parametersRow = [];
        foreach ($reportStrategy['parameterMapping'] as $fieldName => $paramName) {
            $parametersRow[$paramName] = $row[$fieldName];
        }
        
        $parametersRow['NRORG'] = $this->nrorg;
        $parametersRow['__format'] = $row["__FORMAT"];
        $birtURL = $this->reportService->createRemoteReport('BIRT', $reportName, $parametersRow);
        $response->addMessage(new DTO\Response\Message($birtURL));
    }
    
    private function getReportStrategyReport($reportName) {
        $reportStrategy = [
            'strategy' => 'BIRT'
        ];
        switch($reportName) {
            case 'EST40000':
                $reportStrategy['parameterMapping'] = [
                    "CDANO" => "CDANO",
                    "CDTRIMESTRE" => "CDTRIMESTRE",
                    "CDEMPRESA" => "CDEMPRESA",
                    "NRTPFISCALPROD" => "NRTPFISCALPROD",
                    "DTINICIAL" => "DTINICIAL",
                    "DTFINAL" => "DTFINAL"
                ];
                break;
            case 'EST400001':
            case 'EST400002':
                $reportStrategy['parameterMapping'] = [
                    "CDANO" => "CDANO",
                    "CDTRIMESTRE" => "CDTRIMESTRE",
                    "CDEMPRESA" => "CDEMPRESA",
                    "NRTPFISCALPROD" => "NRTPFISCALPROD"
                ];
                break;
        }
        return $reportStrategy;
    }
}
